@@ -9,13 +9,16 @@ package org.sablecc.sablecc;
 
 final class LR0ItemAndSetPair
 {
-    public final LR0Item item;
-    public final int set;
+  public final LR0Item item;
+  public final int set
+    ;
 
-    LR0ItemAndSetPair(LR0Item item, int set)
-    {
-        this.item = item;
-        this.set = set;
-    }
+  LR0ItemAndSetPair(LR0Item item, int set
+                     )
+  {
+    this.item = item;
+    this.set = set
+                 ;
+  }
 }
 
